@@ -3,15 +3,15 @@ from functools import wraps
 import numpy as np
 
 from ..base import normalize_token
+from ..utils import derived_from
 from .core import (
-    concatenate_lookup,
-    tensordot_lookup,
-    map_blocks,
     asanyarray,
     blockwise,
+    concatenate_lookup,
+    map_blocks,
+    tensordot_lookup,
 )
 from .routines import _average
-from ..utils import derived_from
 
 
 @normalize_token.register(np.ma.masked_array)
@@ -254,7 +254,7 @@ def set_fill_value(a, fill_value):
     fill_value = np.ma.core._check_fill_value(fill_value, a.dtype)
     res = a.map_blocks(_set_fill_value, fill_value)
     a.dask = res.dask
-    a.name = res.name
+    a._name = res.name
 
 
 @derived_from(np.ma)
