@@ -6,6 +6,7 @@ import uuid
 from collections import OrderedDict
 from contextlib import contextmanager
 from dataclasses import fields, is_dataclass
+from distutils.version import LooseVersion
 from functools import partial
 from hashlib import md5
 from numbers import Number
@@ -897,6 +898,8 @@ def _normalize_function(func):
 def register_pandas():
     import pandas as pd
 
+    PANDAS_GT_130 = LooseVersion(pd.__version__) >= LooseVersion("1.3.0")
+
     @normalize_token.register(pd.Index)
     def normalize_index(ind):
         values = ind.array
@@ -934,13 +937,21 @@ def register_pandas():
         return [
             s.name,
             s.dtype,
-            normalize_token(s._data.blocks[0].values),
+            normalize_token(s._values),
             normalize_token(s.index),
         ]
 
     @normalize_token.register(pd.DataFrame)
     def normalize_dataframe(df):
-        data = [block.values for block in df._data.blocks]
+        mgr = df._data
+
+        if PANDAS_GT_130:
+            # for compat with ArrayManager, pandas 1.3.0 introduced a `.arrays`
+            # attribute that returns the column arrays/block arrays for both
+            # BlockManager and ArrayManager
+            data = list(mgr.arrays)
+        else:
+            data = [block.values for block in mgr.blocks]
         data.extend([df.columns, df.index])
         return list(map(normalize_token, data))
 
