@@ -1,8 +1,11 @@
+import copy
 from distutils.version import LooseVersion
 
 from fsspec.core import get_fs_token_paths
 
 from ...base import tokenize
+from ...highlevelgraph import HighLevelGraph
+from ...layers import DataFrameIOLayer
 from ...utils import import_required
 from ..core import DataFrame
 from .utils import _get_pyarrow_dtypes, _meta_from_dtypes
@@ -10,6 +13,37 @@ from .utils import _get_pyarrow_dtypes, _meta_from_dtypes
 __all__ = ("read_orc",)
 
 
+class ORCFunctionWrapper:
+    """
+    ORC Function-Wrapper Class
+    Reads ORC data from disk to produce a partition.
+    """
+
+    def __init__(self, fs, columns, schema):
+        self.fs = fs
+        self.columns = columns
+        self.schema = schema
+
+    def project_columns(self, columns):
+        """Return a new ORCFunctionWrapper object with
+        a sub-column projection.
+        """
+        if columns == self.columns:
+            return self
+        func = copy.deepcopy(self)
+        func.columns = columns
+        return func
+
+    def __call__(self, stripe_info):
+        path, stripe = stripe_info
+        return _read_orc_stripe(
+            self.fs,
+            path,
+            stripe,
+            list(self.schema) if self.columns is None else self.columns,
+        )
+
+
 def _read_orc_stripe(fs, path, stripe, columns=None):
     """Pull out specific data from specific part of ORC file"""
     orc = import_required("pyarrow.orc", "Please install pyarrow >= 0.9.0")
@@ -26,7 +60,6 @@ def _read_orc_stripe(fs, path, stripe, columns=None):
 
 def read_orc(path, columns=None, storage_options=None):
     """Read dataframe from ORC file(s)
-
     Parameters
     ----------
     path: str or list(str)
@@ -36,11 +69,9 @@ def read_orc(path, columns=None, storage_options=None):
         Columns to load. If None, loads all.
     storage_options: None or dict
         Further parameters to pass to the bytes backend.
-
     Returns
     -------
     Dask.DataFrame (even if there is only one column)
-
     Examples
     --------
     >>> df = dd.read_orc('https://github.com/apache/orc/raw/'
@@ -64,7 +95,7 @@ def read_orc(path, columns=None, storage_options=None):
         path, mode="rb", storage_options=storage_options
     )
     schema = None
-    nstripes_per_file = []
+    parts = []
     for path in paths:
         with fs.open(path, "rb") as f:
             o = orc.ORCFile(f)
@@ -72,7 +103,8 @@ def read_orc(path, columns=None, storage_options=None):
                 schema = o.schema
             elif schema != o.schema:
                 raise ValueError("Incompatible schemas while parsing ORC files")
-            nstripes_per_file.append(o.nstripes)
+        for stripe in range(o.nstripes):
+            parts.append((path, stripe))
     schema = _get_pyarrow_dtypes(schema, categories=None)
     if columns is not None:
         ex = set(columns) - set(schema)
@@ -80,16 +112,19 @@ def read_orc(path, columns=None, storage_options=None):
             raise ValueError(
                 "Requested columns (%s) not in schema (%s)" % (ex, set(schema))
             )
-    else:
-        columns = list(schema)
+
+    # Create Blockwise layer
+    label = "read-orc-"
+    output_name = label + tokenize(fs_token, path, columns)
+    layer = DataFrameIOLayer(
+        output_name,
+        columns,
+        parts,
+        ORCFunctionWrapper(fs, columns, schema),
+        label=label,
+    )
+
+    columns = list(schema) if columns is None else columns
     meta = _meta_from_dtypes(columns, schema, [], [])
-
-    name = "read-orc-" + tokenize(fs_token, path, columns)
-    dsk = {}
-    N = 0
-    for path, n in zip(paths, nstripes_per_file):
-        for stripe in range(n):
-            dsk[(name, N)] = (_read_orc_stripe, fs, path, stripe, columns)
-            N += 1
-
-    return DataFrame(dsk, name, meta, [None] * (len(dsk) + 1))
+    graph = HighLevelGraph({output_name: layer}, {output_name: set()})
+    return DataFrame(graph, output_name, meta, [None] * (len(parts) + 1))
