@@ -20,6 +20,7 @@ from dask.bytes.utils import compress
 from dask.core import flatten
 from dask.dataframe._compat import tm
 from dask.dataframe.io.csv import (
+    _infer_block_size,
     auto_blocksize,
     block_mask,
     pandas_read_text,
@@ -509,8 +510,11 @@ def test_read_csv_skiprows_range():
 def test_usecols():
     with filetext(timeseries) as fn:
         df = dd.read_csv(fn, blocksize=30, usecols=["High", "Low"])
+        df_select = df[["High"]]
         expected = pd.read_csv(fn, usecols=["High", "Low"])
+        expected_select = expected[["High"]]
         assert (df.compute().values == expected.values).all()
+        assert (df_select.compute().values == expected_select.values).all()
 
 
 def test_string_blocksize():
@@ -784,6 +788,23 @@ def test_auto_blocksize():
     assert auto_blocksize(5000, 2) == 250
 
 
+def test__infer_block_size(monkeypatch):
+    """
+    psutil returns a total memory of `None` on some systems
+    see https://github.com/dask/dask/pull/7601
+    """
+    psutil = pytest.importorskip("psutil")
+
+    class MockOutput:
+        total = None
+
+    def mock_virtual_memory():
+        return MockOutput
+
+    monkeypatch.setattr(psutil, "virtual_memory", mock_virtual_memory)
+    assert _infer_block_size()
+
+
 def test_auto_blocksize_max64mb():
     blocksize = auto_blocksize(1000000000000, 3)
     assert blocksize == int(64e6)
