@@ -1,7 +1,7 @@
 """ Dataframe optimizations """
 import operator
 
-from dask.base import tokenize
+import numpy as np
 
 from .. import config, core
 from ..blockwise import Blockwise, fuse_roots, optimize_blockwise
@@ -17,12 +17,16 @@ def optimize(dsk, keys, **kwargs):
 
     if not isinstance(dsk, HighLevelGraph):
         dsk = HighLevelGraph.from_collections(id(dsk), dsk, dependencies=())
-
-    dsk = optimize_read_parquet_getitem(dsk, keys=keys)
-    dsk = optimize_blockwise(dsk, keys=keys)
-    dsk = fuse_roots(dsk, keys=keys)
+    else:
+        # Perform Blockwise optimizations for HLG input
+        dsk = optimize_dataframe_getitem(dsk, keys=keys)
+        dsk = optimize_blockwise(dsk, keys=keys)
+        dsk = fuse_roots(dsk, keys=keys)
     dsk = dsk.cull(set(keys))
 
+    # Do not perform low-level fusion unless the user has
+    # specified True explicitly. The configuration will
+    # be None by default.
     if not config.get("optimization.fuse.active"):
         return dsk
 
@@ -42,23 +46,32 @@ def optimize(dsk, keys, **kwargs):
     return dsk
 
 
-def optimize_read_parquet_getitem(dsk, keys):
-    # find the keys to optimize
-    from .io.parquet.core import ParquetSubgraph
+def optimize_dataframe_getitem(dsk, keys):
+    # This optimization looks for all `DataFrameLayer` instances,
+    # and calls `project_columns` on any layers that directly precede
+    # a (qualified) `getitem` operation. In the future, we can
+    # search for `getitem` operations instead, and work backwards
+    # through multiple adjacent `DataFrameLayer`s. This approach
+    # may become beneficial once `DataFrameLayer` is made a base
+    # type for all relevant DataFrame operations.
 
-    read_parquets = [k for k, v in dsk.layers.items() if isinstance(v, ParquetSubgraph)]
+    from ..layers import DataFrameLayer
+
+    dataframe_blockwise = [
+        k for k, v in dsk.layers.items() if isinstance(v, DataFrameLayer)
+    ]
 
     layers = dsk.layers.copy()
     dependencies = dsk.dependencies.copy()
 
-    for k in read_parquets:
+    for k in dataframe_blockwise:
         columns = set()
         update_blocks = {}
 
         for dep in dsk.dependents[k]:
             block = dsk.layers[dep]
 
-            # Check if we're a read_parquet followed by a getitem
+            # Check if we're a dataframe_blockwise followed by a getitem
             if not isinstance(block, Blockwise):
                 # getitem are Blockwise...
                 return dsk
@@ -72,7 +85,7 @@ def optimize_read_parquet_getitem(dsk, keys):
                 return dsk
 
             if any(layers[k].name == x[0] for x in keys if isinstance(x, tuple)):
-                # ... but bail on the optimization if the read_parquet layer is in
+                # ... but bail on the optimization if the dataframe_blockwise layer is in
                 # the requested keys, because we cannot change the name anymore.
                 # These keys are structured like [('getitem-<token>', 0), ...]
                 # so we check for the first item of the tuple.
@@ -80,25 +93,24 @@ def optimize_read_parquet_getitem(dsk, keys):
                 return dsk
 
             block_columns = block.indices[1][0]
-            if isinstance(block_columns, str):
+            if isinstance(block_columns, str) or np.issubdtype(
+                type(block_columns), np.integer
+            ):
                 block_columns = [block_columns]
-
             columns |= set(block_columns)
             update_blocks[dep] = block
 
+        # Project columns and update blocks
         old = layers[k]
-
-        if columns and columns < set(old.meta.columns):
+        new = old.project_columns(columns)[0]
+        if new.name != old.name:
             columns = list(columns)
-            meta = old.meta[columns]
-            name = "read-parquet-" + tokenize(old.name, columns)
             assert len(update_blocks)
-
             for block_key, block in update_blocks.items():
                 # (('read-parquet-old', (.,)), ( ... )) ->
                 # (('read-parquet-new', (.,)), ( ... ))
-                new_indices = ((name, block.indices[0][1]), block.indices[1])
-                numblocks = {name: block.numblocks[old.name]}
+                new_indices = ((new.name, block.indices[0][1]), block.indices[1])
+                numblocks = {new.name: block.numblocks[old.name]}
                 new_block = Blockwise(
                     block.output,
                     block.output_indices,
@@ -109,29 +121,11 @@ def optimize_read_parquet_getitem(dsk, keys):
                     block.new_axes,
                 )
                 layers[block_key] = new_block
-                dependencies[block_key] = {name}
-            dependencies[name] = dependencies.pop(k)
+                dependencies[block_key] = {new.name}
+            dependencies[new.name] = dependencies.pop(k)
 
-        else:
-            # Things like df[df.A == 'a'], where the argument to
-            # getitem is not a column name
-            name = old.name
-            meta = old.meta
-            columns = list(meta.columns)
-
-        new = ParquetSubgraph(
-            name,
-            old.engine,
-            old.fs,
-            meta,
-            columns,
-            old.index,
-            old.parts,
-            old.kwargs,
-            common_kwargs=old.common_kwargs,
-        )
-        layers[name] = new
-        if name != old.name:
+        layers[new.name] = new
+        if new.name != old.name:
             del layers[old.name]
 
     new_hlg = HighLevelGraph(layers, dependencies)
