@@ -1,13 +1,12 @@
 from distutils.version import LooseVersion
 
+import numpy as np
 import pandas as pd
 import pytest
-import numpy as np
 
 import dask.dataframe as dd
-from dask.dataframe.utils import assert_eq
 from dask.dataframe._compat import PANDAS_GT_130
-
+from dask.dataframe.utils import assert_eq
 
 N = 40
 df = pd.DataFrame(
@@ -72,15 +71,13 @@ def test_map_overlap_names():
     res3 = ddf.map_overlap(shifted_sum, 0, 3, 0, 3, c=3)
     assert res3._name != res._name
     # Difference is just the final map
-    diff = set(res3.dask).difference(res.dask)
+    diff = res3.dask.keys() - res.dask.keys()
     assert len(diff) == npartitions
 
     res4 = ddf.map_overlap(shifted_sum, 3, 0, 0, 3, c=2)
     assert res4._name != res._name
 
 
-# TODO(pandas) fix Index.is_all_dates deprecation
-@pytest.mark.filterwarnings(r"ignore:Index\.is_all_dates:FutureWarning")
 def test_map_overlap_errors():
     # Non-integer
     with pytest.raises(ValueError):
@@ -252,7 +249,6 @@ def test_rolling_repr():
 
 # TODO(pandas) fix rolling to be compatible with pandas 1.3.0
 @pytest.mark.skipif(PANDAS_GT_130, reason="win_type changed in pandas master")
-@pytest.mark.filterwarnings(r"ignore:Index\.is_all_dates:FutureWarning")
 def test_time_rolling_repr():
     res = repr(dts.rolling("4s"))
     assert res == "Rolling [window=4000000000,center=False,win_type=freq,axis=0]"
@@ -260,7 +256,6 @@ def test_time_rolling_repr():
 
 # TODO(pandas) fix rolling to be compatible with pandas 1.3.0
 @pytest.mark.skipif(PANDAS_GT_130, reason="win_type changed in pandas master")
-@pytest.mark.filterwarnings(r"ignore:Index\.is_all_dates:FutureWarning")
 def test_time_rolling_constructor():
     result = dts.rolling("4s")
     assert result.window == "4s"
@@ -274,7 +269,6 @@ def test_time_rolling_constructor():
 
 # TODO(pandas) fix rolling to be compatible with pandas 1.3.0
 @pytest.mark.filterwarnings("ignore:win_type:FutureWarning")
-@pytest.mark.filterwarnings(r"ignore:Index\.is_all_dates:FutureWarning")
 @pytest.mark.parametrize(
     "method,args,check_less_precise", rolling_method_args_check_less_precise
 )
@@ -313,7 +307,6 @@ def test_time_rolling_methods(method, args, window, check_less_precise):
 
 # TODO(pandas) fix rolling to be compatible with pandas 1.3.0
 @pytest.mark.filterwarnings("ignore:win_type:FutureWarning")
-@pytest.mark.filterwarnings(r"ignore:Index\.is_all_dates:FutureWarning")
 @pytest.mark.parametrize("window", ["1S", "2S", "3S", pd.offsets.Second(5)])
 def test_time_rolling_cov(window):
     # DataFrame
@@ -329,7 +322,6 @@ def test_time_rolling_cov(window):
 
 # TODO(pandas) fix rolling to be compatible with pandas 1.3.0
 @pytest.mark.filterwarnings("ignore:win_type:FutureWarning")
-@pytest.mark.filterwarnings(r"ignore:Index\.is_all_dates:FutureWarning")
 @pytest.mark.parametrize(
     "window,N",
     [("1s", 10), ("2s", 10), ("10s", 10), ("10h", 10), ("10s", 100), ("10h", 100)],
@@ -350,7 +342,6 @@ def test_time_rolling_large_window_fixed_chunks(window, N):
 
 # TODO(pandas) fix rolling to be compatible with pandas 1.3.0
 @pytest.mark.filterwarnings("ignore:win_type:FutureWarning")
-@pytest.mark.filterwarnings(r"ignore:Index\.is_all_dates:FutureWarning")
 @pytest.mark.parametrize("window", ["2s", "5s", "20s", "10h"])
 def test_time_rolling_large_window_variable_chunks(window):
     df = pd.DataFrame(
@@ -369,7 +360,6 @@ def test_time_rolling_large_window_variable_chunks(window):
 
 
 # TODO(pandas) fix rolling to be compatible with pandas 1.3.0
-@pytest.mark.filterwarnings(r"ignore:Index\.is_all_dates:FutureWarning")
 @pytest.mark.parametrize("before, after", [("6s", "6s"), ("2s", "2s"), ("6s", "2s")])
 def test_time_rolling(before, after):
     window = before
