@@ -57,12 +57,39 @@ class Layer(collections.abc.Mapping):
     """
 
     annotations: Optional[Mapping[str, Any]]
+    collection_annotations: Optional[Mapping[str, Any]]
 
-    def __init__(self, annotations: Mapping[str, Any] = None):
+    def __init__(
+        self,
+        annotations: Mapping[str, Any] = None,
+        collection_annotations: Mapping[str, Any] = None,
+    ):
+        """Initialize Layer object.
+
+        Parameters
+        ----------
+        annotations : Mapping[str, Any], optional
+            By default, None.
+            Annotations are metadata or soft constraints associated with tasks
+            that dask schedulers may choose to respect:
+            They signal intent without enforcing hard constraints.
+            As such, they are primarily designed for use with the distributed
+            scheduler. See the dask.annotate function for more information.
+        collection_annotations : Mapping[str, Any], optional. By default, None.
+            Experimental, intended to assist with visualizing the performance
+            characteristics of Dask computations.
+            These annotations are *not* passed to the distributed scheduler.
+        """
         if annotations:
             self.annotations = annotations
         else:
             self.annotations = copy.copy(config.get("annotations", None))
+        if collection_annotations:
+            self.collection_annotations = collection_annotations
+        else:
+            self.collection_annotations = copy.copy(
+                config.get("collection_annotations", None)
+            )
 
     @abc.abstractmethod
     def is_materialized(self) -> bool:
@@ -147,29 +174,32 @@ class Layer(collections.abc.Mapping):
         """
         return keys_in_tasks(all_hlg_keys, [self[key]])
 
-    def __dask_distributed_annotations_pack__(self) -> Optional[Mapping[str, Any]]:
+    def __dask_distributed_annotations_pack__(
+        self, annotations: Mapping[str, Any] = None
+    ) -> Optional[Mapping[str, Any]]:
         """Packs Layer annotations for transmission to scheduler
 
         Callables annotations are fully expanded over Layer keys, while
         other values are simply transmitted as is
 
+        Parameters
+        ----------
+        annotations : Mapping[str, Any], optional
+            A top-level annotations.
+
         Returns
         -------
         packed_annotations : dict
             Packed annotations.
         """
-        if self.annotations is None:
-            return None
-
+        annotations = toolz.merge(self.annotations or {}, annotations or {})
         packed = {}
-
-        for a, v in self.annotations.items():
+        for a, v in annotations.items():
             if callable(v):
                 packed[a] = {stringify(k): v(k) for k in self}
                 packed[a]["__expanded_annotations__"] = True
             else:
                 packed[a] = v
-
         return packed
 
     @staticmethod
@@ -377,6 +407,7 @@ class Layer(collections.abc.Mapping):
         }
         for k, v in unpacked_futures_deps.items():
             dependencies[k] = set(dependencies.get(k, ())) | v
+        dependencies.update(known_key_dependencies)
 
         # The scheduler expect all keys to be strings
         dependencies = {
@@ -924,7 +955,10 @@ class HighLevelGraph(Mapping):
                 )
 
     def __dask_distributed_pack__(
-        self, client, client_keys: Iterable[Hashable]
+        self,
+        client,
+        client_keys: Iterable[Hashable],
+        annotations: Mapping[str, Any] = None,
     ) -> dict:
         """Pack the high level graph for Scheduler -> Worker communication
 
@@ -937,8 +971,10 @@ class HighLevelGraph(Mapping):
         ----------
         client : distributed.Client
             The client calling this function.
-        client_keys : Iterable
+        client_keys : Iterable[Hashable]
             List of keys requested by the client.
+        annotations : Mapping[str, Any], optional
+            A top-level annotations.
 
         Returns
         -------
@@ -958,13 +994,15 @@ class HighLevelGraph(Mapping):
                         client,
                         client_keys,
                     ),
-                    "annotations": layer.__dask_distributed_annotations_pack__(),
+                    "annotations": layer.__dask_distributed_annotations_pack__(
+                        annotations
+                    ),
                 }
             )
         return {"layers": layers}
 
     @staticmethod
-    def __dask_distributed_unpack__(hlg: dict, annotations: Mapping[str, Any]) -> Dict:
+    def __dask_distributed_unpack__(hlg: dict) -> dict:
         """Unpack the high level graph for Scheduler -> Worker communication
 
         The approach is to delegate the unpackaging to each layer in the high level graph
@@ -975,10 +1013,6 @@ class HighLevelGraph(Mapping):
         ----------
         hlg: dict
             Packed high level graph layers
-        annotations : dict
-            A top-level annotations object which may be partially populated,
-            and which may be further filled by annotations from the layers
-            of the packed_hlg.
 
         Returns
         -------
@@ -1015,11 +1049,7 @@ class HighLevelGraph(Mapping):
                 deps[k] = deps.get(k, set()) | v
 
             # Unpack the annotations
-            if annotations and layer["annotations"]:
-                layer_annotations = {**layer["annotations"], **annotations}
-            else:
-                layer_annotations = annotations or layer["annotations"] or None
-            unpack_anno(anno, layer_annotations, unpacked_layer["dsk"].keys())
+            unpack_anno(anno, layer["annotations"], unpacked_layer["dsk"].keys())
 
         return {"dsk": dsk, "deps": deps, "annotations": anno}
 
